@@ -36,7 +36,7 @@ Version 2.4.2
 
 =cut
 
-our $VERSION = '2.43';
+our $VERSION = '2.44';
 
 =head1 SYNOPSIS
 
@@ -172,6 +172,13 @@ You shouldn't be calling these directly.
 
 =cut
 
+has 'dt' => (
+    is => 'rw',
+    isa => 'DateTime',
+    default => sub { return DateTime->now(time_zone => 'local'); },
+    lazy => 1,
+);
+
 =head2 jobref
 
 Array of arrays details slurm/process/scheduler job id. Index -1 is the most recent job submissisions, and there will be an index -2 if there are any job dependencies
@@ -243,7 +250,7 @@ has 'logfile' => (
     is => 'rw',
     default => \&set_logfile,
     handles => {
-        add_logfile => 'append',
+        append_logfile => 'append',
         prepend_logfile => 'prepend',
         clear_logfile => 'clear',
     }
@@ -292,7 +299,8 @@ sub set_logdir{
     use Carp::Always;
     use Data::Dumper;
     #confess(Dumper($self));
-    $logdir = $self->outdir."/".$self->logname."_".$self->set_logfile;
+    #$logdir = $self->outdir."/".$self->logname."_".$self->set_logfile;
+    $logdir = $self->outdir."/".$self->set_logfile."-".$self->logname;
 
     $DB::single=2;
     $logdir =~ s/\.log$//;
@@ -310,9 +318,8 @@ Set logfile
 sub set_logfile{
     my $self = shift;
 
-    my $dt = DateTime->now();
-    $dt =~ s/[^\w]/_/g;
-    return "$dt.log";
+    my $tt = $self->dt->ymd();
+    return "$tt";
 }
 
 =head2 init_log
@@ -397,12 +404,12 @@ sub _log_commands {
     my($self, $pid) = @_;
 
     #same here
-    my $dt1 = DateTime->now();
+    #my $dt1 = DateTime->now();
+    my $dt1 = $self->dt;
 
     $DB::single=2;
 
-    $self->logfile($self->set_logfile);
-    $self->prepend_logfile("CMD".$self->counter."_PID_$pid"."_DT_");
+    $self->name_log($pid);
     $DB::single=2;
 
     $self->command_log($self->init_log);
@@ -423,6 +430,14 @@ sub _log_commands {
     return $exitcode;
 }
 
+sub name_log {
+    my $self = shift;
+    my $pid = shift;
+
+    $self->logfile($self->set_logfile);
+    $self->append_logfile("-CMD".$self->counter."-PID_$pid.log");
+}
+
 ##TODO extend this in HPC-Runner-Web for ENV tags
 sub log_table {
     my $self = shift;
